Usage
panel.polarPlot(x = NULL, y = NULL, r = NULL, theta = NULL, ...,
data.panel = panel.loaPlot, loa.settings = FALSE,
plot = TRUE, process = TRUE)
#grid, axes and axes labelling
panel.polarFrame(..., grid = TRUE, axes = TRUE, labels = TRUE,
panel.scales = NULL, grid.panel = panel.polarGrid,
axes.panel = panel.polarAxes, labels.panel = panel.polarLabels)
panel.polarAxes(axes.theta = NULL, axes.r = NULL, thetalim = NULL,
rlim = NULL, ..., axes = NULL, panel.scales = NULL)
panel.polarGrid(grid.theta = NULL, grid.r = NULL,
thetalim = NULL, rlim = NULL, ..., grid = NULL,
panel.scales = NULL)
panel.polarLabels(labels.theta = NULL, labels.r = NULL,
thetalim = NULL, rlim = NULL, ..., labels = NULL,
panel.scales = NULL)Arguments
x, y
The x and y coordinates of plot points.
r, theta
The equivalent polar coordinates of the plot
points. If these are not supplied, x and y are
assumed to be polar coordinates and these are calculated
by the function.
...
Additional arguments, typically passed on. For
panel.polarPlot these are passed to the data.panel.
See below.
data.panel
The panel to use to handle data once polar
coordinates have been checked for or generated. For
panel.polarPlot, by default this is panel.loaPlot.
loa.settings, plot, process
loa panel management
arguments, handled by panelPal. See associated
help documentation for further details.grid, axes, labels
plot management options for the grid, axis
and axis label elements of the plot. These can be logicals (TRUE
to include the element or FALSE to remove it) or lists of plot
parameters.
panel.scales
loa plot management argument used when
generating grids, axes and labels within the plot panel.
grid.panel, axes.panel, labels.panel
Used by the panel...Frame
functions to identify the panel... functions to use when
generating the grid, axes and axis labelling elements of the plot.
axes.theta, axes.r, thetalim, rlim
For panel.polarAxes
axes settings. axes.theta and axes.r are the theta and
r coordinates of the axis reference points, tick marks, etc.
thetalim and rlim
grid.theta, grid.r
Like axes.theta and axes.r but for
grid.
labels.theta, labels.r
Like axes.theta and axes.r but for
labels.