In development specialist panel functions for generating zcase glyph structures.
panel.zcasePiePlot(..., loa.settings = FALSE)panel.zcasePieSegmentPlot(..., zcase.rescale=TRUE,
loa.settings = FALSE)
These panel... functions are intended to be used as the
panel argument in loa plot calls. So, e.g.:
a <- 1:10
b <- 10:1
loaPlot(a+b~a*a, panel=panel.zcasePiePlot)
loaPlot(a+b~a*a, panel=panel.zcasePieSegmentPlot)
Additional arguments, typically setting the color and properties of the plotted glyphs. See below.
Should the glyph element be rescaled? See below.
loa options, to be handled by panelPal.
Karl Ropkins
All these panel... functions generate glyphs using z inputs and plot these
at the associated (x, y) location. So, for example a called which used one of the panels
and the plot formula:
z1 + z2+ z3 + z4 ~ x * y
... would plot a series of glyphs, each containing four elements that would be scaled
according to z1, z2, z3 and z4, and each at the associated
(x, y) location. This means there will be one discrete glyph for each row of data supplied
to the plot call.
panel.zcasePiePlot generates a series of x/y referenced pie graphs. By default, pie
dimensions are assigned as: Pie size (radius) proportional to sum of z cases and scaled using
cexHandler (z1 + z2 + z3 + z4 for the above formula); Number of Pie segments
equal to number of z cases (so, 4 for the above formula); Pie segment width (phi) proportional to
the individual zcase (so, z1 / (z1 + z2 + z3 + z4) * 360 for first pie segment for the above
formula).
panel.zcasePieSegmentPlot is a variation on the conventional pie plot where segement radius
rather than segment width is varying by zcase.
These function makes extensive use of code developed by others.
lattice: Sarkar, Deepayan (2008) Lattice: Multivariate Data Visualization with R. Springer, New York. ISBN 978-0-387-75968-5