Usage
loaPolygon(x, y, ..., polygon = NULL,
loa.scale = NULL)
loaCircle(..., polygon = NULL, radius = 1)
loaPieSegment(..., polygon = NULL, start = 0,
angle=360, radius = 1, center=TRUE)Arguments
x, y
The x and y points at which to plot the
requested shape.
...
Any additional arguments, usually passed on.
polygon
A list with elements x and y giving the
polygon/shape to be plotted.
loa.scale
A list of parameters that can be used to fine-tune the
polygon plotting.
radius
The radius to used when drawing either circles or pie segments.
start, angle
When drawing pie segments, angle the angle of
of the segment and start point.
center
Should the segement begin and end at the center?