General functions for adding extra layers to existing plots.
add_loaPanel(lattice.plot=trellis.last.object(),
preprocess = NULL, panel = NULL,
postprocess = NULL, ...)The plot to add an extra layer or layers to. This defaults to last lattice plot produced if not set in call.
If set, a function to apply to
lattice.plot before adding new panel.
If set, a new panel... function to add to
lattice.plot after the current lattice.plot panel.
If set, a function to apply to
lattice.plot after adding new panel.
Additional arguments, passed on to related functions.
add_loaPanel returns the supply (or last) lattice plot
with an additional plot layer added.
add_loaPanel is a frame work function for adding
additional layers to an exiting lattice plot.
This function makes extensive use of code developed by others.
lattice: Sarkar, Deepayan (2008) Lattice: Multivariate Data Visualization with R. Springer, New York. ISBN 978-0-387-75968-5
Grid (part of base R): R Core Team (2017). R: A language and environment for statistical computing. R Foundation for Statistical Computing, Vienna, Austria. URL https://www.R-project.org/.